<?php

// Admin stuff for Recent Posts Plugin, Version 2.5.0

function recent_posts_option_menu() {
	add_options_page(__('Recent Posts Options', 'post_plugins'), __('Recent Posts', 'post_plugins'), 8, 'recent-posts', 'recent_posts_options_page');
}

add_action('admin_menu', 'recent_posts_option_menu', 1);

function recent_posts_options_page(){
	echo '<div class="wrap"><h2>';
	_e('Recent Posts ', 'post_plugins'); 
	echo '<a href="http://rmarsh.com/plugins/post-options/" style="font-size: 0.8em;">';
	_e('help and instructions'); 
	echo '</a></h2></div>';
	if (!RecentPosts::check_post_plugin_library(__('<h1>Please install the <a href="http://downloads.wordpress.org/plugin/post-plugin-library.zip">Post Plugin Library</a> plugin.</h1>'))) return;
	$m = new admin_subpages();
	$m->add_subpage('General', 'general', 'recent_posts_general_options_subpage');
	$m->add_subpage('Output', 'output', 'recent_posts_output_options_subpage');
	$m->add_subpage('Filter', 'filter', 'recent_posts_filter_options_subpage');
	$m->add_subpage('Other', 'other', 'recent_posts_other_options_subpage');
	$m->add_subpage('Report a Bug', 'bug', 'recent_posts_bug_subpage');
	$m->add_subpage('Remove this Plugin', 'remove', 'recent_posts_remove_subpage');
	$m->display();
}

function recent_posts_general_options_subpage(){
	global $wpdb, $wp_version;
	$options = get_option('recent-posts');
	if (isset($_POST['update_options'])) {
		check_admin_referer('recent-posts-update-options'); 
		if (defined('POC_CACHE_4')) poc_cache_flush();
		// Fill up the options with the values chosen...
		$options = ppl_options_from_post($options, array('limit', 'skip', 'show_private', 'show_pages', 'age', 'omit_current_post', 'match_cat', 'match_tags'));
		update_option('recent-posts', $options);
		// Show a message to say we've done something
		echo '<div class="updated fade"><p>' . __('Options saved', 'post_plugins') . '</p></div>';
	} 
	//now we drop into html to display the option page form
	?>
		<div class="wrap">
		<h2><?php _e('General Settings', 'post_plugins'); ?></h2>
		<form method="post" action="">
		<div class="submit"><input type="submit" name="update_options" value="<?php _e('Save General Settings', 'post_plugins') ?>" /></div>
		<table class="optiontable form-table">
			<?php 
				ppl_display_limit($options['limit']); 
				ppl_display_skip($options['skip']); 
				ppl_display_show_private($options['show_private']); 
				ppl_display_show_pages($options['show_pages']); 
				ppl_display_age($options['age']);
				ppl_display_omit_current_post($options['omit_current_post']); 
				ppl_display_match_cat($options['match_cat']); 
				ppl_display_match_tags($options['match_tags']); 
			?>
		</table>
		<div class="submit"><input type="submit" name="update_options" value="<?php _e('Save General Settings', 'post_plugins') ?>" /></div>
		<?php if (function_exists('wp_nonce_field')) wp_nonce_field('recent-posts-update-options'); ?>
		</form>  
	</div>
	<?php	
}

function recent_posts_output_options_subpage(){
	global $wpdb, $wp_version;
	$options = get_option('recent-posts');
	if (isset($_POST['update_options'])) {
		check_admin_referer('recent-posts-update-options'); 
		if (defined('POC_CACHE_4')) poc_cache_flush();
		// Fill up the options with the values chosen...
		$options = ppl_options_from_post($options, array('output_template', 'prefix', 'suffix', 'none_text', 'no_text', 'divider', 'sort', 'group_template'));
		update_option('recent-posts', $options);
		// Show a message to say we've done something
		echo '<div class="updated fade"><p>' . __('Options saved', 'post_plugins') . '</p></div>';
	} 
	//now we drop into html to display the option page form
	?>
		<div class="wrap">
		<h2><?php _e('Output Settings', 'post_plugins'); ?></h2>
		<form method="post" action="">
		<div class="submit"><input type="submit" name="update_options" value="<?php _e('Save Output Settings', 'post_plugins') ?>" /></div>
		<table class="optiontable form-table">
			<tr>
			<td>
			<table>
			<?php 
				ppl_display_output_template($options['output_template']); 
				ppl_display_prefix($options['prefix']); 
				ppl_display_suffix($options['suffix']); 
				ppl_display_none_text($options['none_text']); 
				ppl_display_no_text($options['no_text']); 
				ppl_display_divider($options['divider']); 
				ppl_display_sort($options['sort']);
				ppl_display_group_template($options['group_template']); 
			?>
			</table>
			</td>
			<td>
			<?php ppl_display_available_tags('recent-posts'); ?>
			</td></tr>
		</table>
		<div class="submit"><input type="submit" name="update_options" value="<?php _e('Save Output Settings', 'post_plugins') ?>" /></div>
		<?php if (function_exists('wp_nonce_field')) wp_nonce_field('recent-posts-update-options'); ?>
		</form>  
	</div>
	<?php	
}

function recent_posts_filter_options_subpage(){
	global $wpdb, $wp_version;
	$options = get_option('recent-posts');
	if (isset($_POST['update_options'])) {
		check_admin_referer('recent-posts-update-options'); 
		if (defined('POC_CACHE_4')) poc_cache_flush();
		// Fill up the options with the values chosen...
		$options = ppl_options_from_post($options, array('excluded_posts', 'included_posts', 'excluded_authors', 'included_authors', 'excluded_cats', 'included_cats', 'tag_str', 'custom'));
		update_option('recent-posts', $options);
		// Show a message to say we've done something
		echo '<div class="updated fade"><p>' . __('Options saved', 'post_plugins') . '</p></div>';
	} 
	//now we drop into html to display the option page form
	?>
		<div class="wrap">
		<h2><?php _e('Filter Settings', 'post_plugins'); ?></h2>
		<form method="post" action="">
		<div class="submit"><input type="submit" name="update_options" value="<?php _e('Save Filter Settings', 'post_plugins') ?>" /></div>
		<table class="optiontable form-table">
			<?php 
				ppl_display_excluded_posts($options['excluded_posts']); 
				ppl_display_included_posts($options['included_posts']); 
				ppl_display_authors($options['excluded_authors'], $options['included_authors']); 
				ppl_display_cats($options['excluded_cats'], $options['included_cats']); 
				ppl_display_tag_str($options['tag_str']); 
				ppl_display_custom($options['custom']); 
			?>
		</table>
		<div class="submit"><input type="submit" name="update_options" value="<?php _e('Save Filter Settings', 'post_plugins') ?>" /></div>
		<?php if (function_exists('wp_nonce_field')) wp_nonce_field('recent-posts-update-options'); ?>
		</form>  
	</div>
	<?php	
}

function recent_posts_other_options_subpage(){
	global $wpdb, $wp_version;
	$options = get_option('recent-posts');
	if (isset($_POST['update_options'])) {
		check_admin_referer('recent-posts-update-options'); 
		if (defined('POC_CACHE_4')) poc_cache_flush();
		// Fill up the options with the values chosen...
		$options = ppl_options_from_post($options, array('content_filter', 'stripcodes'));
		update_option('recent-posts', $options);
		// Show a message to say we've done something
		echo '<div class="updated fade"><p>' . __('Options saved', 'post_plugins') . '</p></div>';
	} 
	//now we drop into html to display the option page form
	?>
		<div class="wrap">
		<h2><?php _e('Other Settings', 'post_plugins'); ?></h2>
		<form method="post" action="">
		<div class="submit"><input type="submit" name="update_options" value="<?php _e('Save Other Settings', 'post_plugins') ?>" /></div>
		<table class="optiontable form-table">
			<?php 
				ppl_display_content_filter($options['content_filter']);
				ppl_display_stripcodes($options['stripcodes']); 
			?>
		</table>
		<div class="submit"><input type="submit" name="update_options" value="<?php _e('Save Other Settings', 'post_plugins') ?>" /></div>
		<?php if (function_exists('wp_nonce_field')) wp_nonce_field('recent-posts-update-options'); ?>
		</form>  
	</div>
	<?php	
}

function recent_posts_bug_subpage(){
	ppl_bug_form('recent-posts'); 
}

function recent_posts_remove_subpage(){
	function eradicate() {
		delete_option('recent-posts');
		delete_option('widget_rrm_recent_posts');
	}
	ppl_plugin_eradicate_form('eradicate', str_replace('-admin', '', __FILE__)); 
}	

function recent_posts_install() {
	$options = get_option('recent-posts');
	// check each of the option values and, if empty, assign a default (doing it this long way
	// lets us retain old values and add new options in later versions)
	if (!isset($options['limit'])) $options['limit'] = 5;
	if (!isset($options['skip'])) $options['skip'] = 0;
	if (!isset($options['age'])) {$options['age']['direction'] = 'none'; $options['age']['length'] = '0'; $options['age']['duration'] = 'month';}
	if (!isset($options['divider'])) $options['divider'] = '';
	if (!isset($options['omit_current_post'])) $options['omit_current_post'] = 'false';
	if (!isset($options['show_private'])) $options['show_private'] = 'false';
	if (!isset($options['show_pages'])) $options['show_pages'] = 'false';
	// show_static is now show_pages
	if ( isset($options['show_static'])) {$options['show_pages'] = $options['show_static']; unset($options['show_static']);};
	if (!isset($options['none_text'])) $options['none_text'] = __('None Found', 'post_plugins');
	if (!isset($options['no_text'])) $options['no_text'] = 'false';
	if (!isset($options['tag_str'])) $options['tag_str'] = '';
	if (!isset($options['excluded_cats'])) $options['excluded_cats'] = '';
	// the '9999' flag is now obsolete
	if ($options['excluded_cats'] === '9999') $options['excluded_cats'] = '';
	if (!isset($options['included_cats'])) $options['included_cats'] = '';
	if ($options['included_cats'] === '9999') $options['included_cats'] = '';
	if (!isset($options['excluded_authors'])) $options['excluded_authors'] = '';
	if ($options['excluded_authors'] === '9999') $options['excluded_authors'] = '';
	if (!isset($options['included_authors'])) $options['included_authors'] = '';
	if ($options['included_authors'] === '9999') $options['included_authors'] = '';
	if (!isset($options['included_posts'])) $options['included_posts'] = '';
	if (!isset($options['excluded_posts'])) $options['excluded_posts'] = '';
	if ($options['excluded_posts'] === '9999') $options['excluded_posts'] = '';
	if (!isset($options['stripcodes'])) $options['stripcodes'] = array(array());
	if (!isset($options['prefix'])) $options['prefix'] = '<ul>';
	if (!isset($options['suffix'])) $options['suffix'] = '</ul>';
	if (!isset($options['output_template'])) $options['output_template'] = '<li>{link}</li>';
	if (!isset($options['match_cat'])) $options['match_cat'] = 'false';
	if (!isset($options['match_tags'])) $options['match_tags'] = 'false';
	if (!isset($options['content_filter'])) $options['content_filter'] = 'false';
	if (!isset($options['custom'])) {$options['custom']['key'] = ''; $options['custom']['op'] = '='; $options['custom']['value'] = '';}
	if (!isset($options['sort'])) {$options['sort']['by1'] = ''; $options['sort']['order1'] = SORT_ASC; $options['sort']['case1'] = 'false';$options['sort']['by2'] = ''; $options['sort']['order2'] = SORT_ASC; $options['sort']['case2'] = 'false';}
	if (!isset($options['group_template'])) $options['group_template'] = '';
	update_option('recent-posts', $options);
}

add_action('activate_'.str_replace('-admin', '', plugin_basename(__FILE__)), 'recent_posts_install');

?>